package TestApp::View::Mason::Appconfig;

use strict;
use warnings;
use base 'Catalyst::View::Mason';

1;
